Within module1.py there is a class which has been created to extract the required data from the UK Gov website.
The cleaned csv should be located under the 'datascraper' directory along with any other output files.
Please install via the pip command 'pip install petroineos_datascraper'